package cviceni1;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.net.Socket;
import java.net.UnknownHostException;

/**
 *
 * <p>Title: Jednoduchý HTTP Client</p>
 *
 * <p>Description: Trida slouzi jako ukazka jak pomoci Socket rozhrani stahnout textovy soubor z www serveru</p>
 * @author Lumír Návrat
 * @version 1.0
 */
public class HTTPSocketClient {

  /**
   * Metoda se pripoji na server a stahne z nej pozadovanou stranku
   * @param server String jmeno www serveru, ze ktereho chceme soubor stahnout
   * @param pageAdress String cesta a jmeno stranky, kterou chceme stahnout
   * @return String pokud vse uspesne probehlo tak vrati zdrojovy kod HTML stranky
   */
  public String getHTMLPage(String server,String pageAdress) {
    // Pomocna promenna, do ktere si ukladame postupne kazdy radek odpovedi ze serveru
    StringBuffer page = new StringBuffer();

    try {
      //Otevreme si spojeni s www serverem
      Socket s = new Socket(server, 80);

      //Obalime si vystupni stream socketu abychom do nej mohli poslat nas pozadavek
      BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(s.getOutputStream()));
      //zapis naseho pozadavku do streamu. Vyuzivame metody GET HTTP protokolu a uvedeme
      //nazev stranky. Pokud bychom potrebovali poslat vice udaju v requesty, tak prislune
      //rozsirime tento retezec.
      bw.write("GET " + pageAdress + " \r\n");
      //Jelikoz pouzivame buffer pro stream, tak ho pro jistotu vyprazdnime do streamu.
      bw.flush();

      //Obdobne si obalime i vstupni stream, ve kterem k nam dorazi data s odpovedi ze serveru.
      BufferedReader br = new BufferedReader(new InputStreamReader(s.getInputStream()));
      //aktualne nacteny jeden radek HTTP odpovedi
      String line = br.readLine();
      //postupne nacitame jeden radek za druhym, dokud mame co cist.
      while (line != null) {
        //vlozime radek do naseho bufferu pro pozdejsi vypis
        page.append(line);
        //nacteme dalsi radek
        line = br.readLine();
      }
      //uzavreme socket, jelikoz s nim uz nechceme pracovat
      s.close();
    } catch(UnknownHostException ex) {
      System.err.println("Adresa www serveru neexistuje");
    } catch(IOException ex) {
      System.err.println("Nastala chyba pri komunikaci");
    }
    return page.toString();
  }

  /**
   * Spousti clienta
   * @param args String[]
   */
  public static void main(String[] args) {
    HTTPSocketClient httpsocketclient = new HTTPSocketClient();
    String server = "www.cs.vsb.cz";
    String pageAdress = "/";
    if (args.length >= 2) {
      server = args[0];
      pageAdress = args[1];
    }
    System.out.println(httpsocketclient.getHTMLPage(server,pageAdress));
  }
}
